@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2019 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2021 Live Networks, Inc.  All rights reserved.
 // A server demultiplexer for a MPEG 1 or 2 Program Stream
 // Implementation
 
@@ -67,7 +67,8 @@ MPEG1or2FileServerDemux::newAC3AudioServerMediaSubsession() {
 MPEG1or2DemuxedElementaryStream*
 MPEG1or2FileServerDemux::newElementaryStream(unsigned clientSessionId,
 					     u_int8_t streamIdTag) {
-  MPEG1or2Demux* demuxToUse;
+  MPEG1or2Demux* demuxToUse = NULL;
+
   if (clientSessionId == 0) {
     // 'Session 0' is treated especially, because its audio & video streams
     // are created and destroyed one-at-a-time, rather than both streams being
@@ -86,28 +87,36 @@ MPEG1or2FileServerDemux::newElementaryStream(unsigned clientSessionId,
   } else {
     // First, check whether this is a new client session.  If so, create a new
     // demux for it:
-    if (clientSessionId != fLastClientSessionId) {
+    if (clientSessionId == fLastClientSessionId) {
+      demuxToUse = fLastCreatedDemux; // use the same demultiplexor as before
+    }
+
+    if (demuxToUse == NULL) {
       // Open our input file as a 'byte-stream file source':
       ByteStreamFileSource* fileSource
 	= ByteStreamFileSource::createNew(envir(), fFileName);
       if (fileSource == NULL) return NULL;
 
-      fLastCreatedDemux = MPEG1or2Demux::createNew(envir(), fileSource, True);
-      // Note: We tell the demux to delete itself when its last
-      // elementary stream is deleted.
-      fLastClientSessionId = clientSessionId;
-      // Note: This code relies upon the fact that the creation of streams for
-      // different client sessions do not overlap - so one "MPEG1or2Demux" is used
-      // at a time.
+      demuxToUse = MPEG1or2Demux::createNew(envir(), fileSource, True, onDemuxDeletion, this);
+        // Note: We tell the demux to delete itself when its last
+        // elementary stream is deleted.
     }
-    demuxToUse = fLastCreatedDemux;
+
+    fLastClientSessionId = clientSessionId;
+    fLastCreatedDemux = demuxToUse;
   }
 
-  if (demuxToUse == NULL) return NULL; // shouldn't happen
-
   return demuxToUse->newElementaryStream(streamIdTag);
 }
 
+void MPEG1or2FileServerDemux::onDemuxDeletion(void* clientData, MPEG1or2Demux* demuxBeingDeleted) {
+  ((MPEG1or2FileServerDemux*)clientData)->onDemuxDeletion(demuxBeingDeleted);
+}
+
+void MPEG1or2FileServerDemux::onDemuxDeletion(MPEG1or2Demux* demuxBeingDeleted) {
+  if (fLastCreatedDemux == demuxBeingDeleted) fLastCreatedDemux = NULL;
+}
+
 
 static Boolean getMPEG1or2TimeCode(FramedSource* dataSource,
 				   MPEG1or2Demux& parentDemux,
